@@ -17,9 +17,9 @@ import atexit
 import json
 import os
 import tempfile
+from unittest import mock
 
 import fixtures
-import mock
 import testtools
 
 from os_apply_config import apply_config
@@ -78,12 +78,6 @@ CHOWN_OUTPUT = {
 }
 
 
-def main_path():
-    return (
-        os.path.dirname(os.path.realpath(__file__)) +
-        '/../os_apply_config.py')
-
-
 def template(relpath):
     return os.path.join(TEMPLATES, relpath[1:])
 
@@ -337,6 +331,11 @@ class OSConfigApplierTestCase(testtools.TestCase):
     def test_render_moustache_bad_key(self):
         self.assertEqual(u'', apply_config.render_moustache("{{badkey}}", {}))
 
+    def test_render_moustache_none(self):
+        self.assertEqual('foo: ',
+                         apply_config.render_moustache("foo: {{foo}}",
+                                                       {'foo': None}))
+
     def test_render_executable(self):
         params = {"x": "foo"}
         self.assertEqual("foo\n", apply_config.render_executable(
